@@ -109,6 +109,12 @@ class CGSmartImage extends CGExtensions
     $this->SetParameterType('quality',CLEAN_INT);
     $this->CreateParameter('quality','75',$this->Lang('param_quality'));
 
+    $this->SetParameterType('rel',CLEAN_STRING);
+    //$this->CreateParameter('title','',$this->Lang('param_title'));
+
+    $this->CreateParameter('max_width','',$this->Lang('param_max_width'));
+    $this->CreateParameter('max_height','',$this->Lang('param_max_height'));
+
     $this->SetParameterType(CLEAN_REGEXP.'/src\d*/',CLEAN_STRING);
     $this->SetParameterType(CLEAN_REGEXP.'/alias\d*/',CLEAN_STRING);
     $this->SetParameterType(CLEAN_REGEXP.'/filter_\w*/',CLEAN_STRING);
@@ -131,6 +137,10 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
 
     $this->RegisterModulePlugin();
+
+    // more smarty plugins
+    $smarty = cmsms()->GetSmarty();
+    $smarty->register_block('cgsi_convert',array('cgsi_utils','cgsi_convert'));
   }
 
   /*---------------------------------------------------------
@@ -156,7 +166,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.3.1';
+    return '1.4';
   }
 
   
@@ -174,7 +184,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.25.2');
+    return array('CGExtensions'=>'1.26');
   }
 
 
