@@ -160,7 +160,7 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 	return $this->_transform_percentage($img);
       }
     if( $this->_width > 0 && $this->_height == 0 && $img['width'] > $this->_width )
-      {
+      { 
 	return $this->_transform_width($img);
       }
     if( $this->_width == 0 && $this->_height > 0 && $img['height'] > $this->_height )
@@ -171,7 +171,8 @@ class CGImage_Resize_Filter extends CGImageFilterBase
       {
 	return $this->_transform_custom($img);
       }
-    // nothing to do.
+    // nothing to do.... but trick the image to be dirty.
+    $img['height'] = $img['height'];
     return $img;
   }
 }
@@ -179,4 +180,4 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
